aboutsummaryrefslogtreecommitdiffstats
path: root/util/mk1mf.pl
diff options
context:
space:
mode:
authorDr. Stephen Henson <steve@openssl.org>1999-02-22 01:26:40 +0000
committerDr. Stephen Henson <steve@openssl.org>1999-02-22 01:26:40 +0000
commite527ba09a66837cad0d8973409e660474db63f89 (patch)
tree9cafa6c8c7d85d4e5cb1957b995ffa815745915d /util/mk1mf.pl
parent60e31c3a4bbdbdb4259eaa3c48639f3e3915f380 (diff)
downloadopenssl-e527ba09a66837cad0d8973409e660474db63f89.tar.gz
Various changes to make this stuff compile under Win32 and VC++ with and
without -debug option to mk1mf.pl. Change _export to is_export (_export is a reserved word under VC++). Add yucky function prototype function pointer casts. Sanitise the included files in crypto/x509v3. Also changed ssleay.exe target to openssl.exe
Diffstat (limited to 'util/mk1mf.pl')
-rwxr-xr-xutil/mk1mf.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/util/mk1mf.pl b/util/mk1mf.pl
index 11e9c16a1e..8da22ccb12 100755
--- a/util/mk1mf.pl
+++ b/util/mk1mf.pl
@@ -249,8 +249,8 @@ $link="$bin_dir$link" if ($link !~ /^\$/);
$INSTALLTOP =~ s|/|$o|g;
$defs= <<"EOF";
# This makefile has been automatically generated from the SSLeay distribution.
# This single makefile will build the complete SSLeay distribution and
# by default leave the 'intertesting' output files in .${o}out and the stuff
# that needs deleting in .${o}tmp.
# The file was generated by running 'make makefile.one', which
@@ -277,7 +277,7 @@ SHLIB_EX_OBJ=$shlib_ex_obj
# be added
EX_LIBS=$ex_libs
-# The SSLeay directory
+# The OpenSSL directory
SRC_D=$src_dir
LINK=$link
@@ -321,7 +321,7 @@ ASM=$bin_dir$asm
# You should not need to touch anything below this point
######################################################
-E_EXE=ssleay
+E_EXE=openssl
SSL=$ssl
CRYPTO=$crypto
RSAGLUE=$RSAglue
@@ -249,8 +249,8 @@ $link="$bin_dir$link" if ($link !~ /^\$/);
$INSTALLTOP =~ s|/|$o|g;
$defs= <<"EOF";
-# This makefile has been automatically generated from the SSLeay distribution.
-# This single makefile will build the complete SSLeay distribution and
+# This makefile has been automatically generated from the OpenSSL distribution.
+# This single makefile will build the complete OpenSSL distribution and
# by default leave the 'intertesting' output files in .${o}out and the stuff
# that needs deleting in .${o}tmp.